@@ -1,4 +1,4 @@
-# Copyright 2004-2017 Tom Rothamel <pytom@bishoujo.us>
+# Copyright 2004-2019 Tom Rothamel <pytom@bishoujo.us>
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation files
@@ -22,6 +22,8 @@
 # This file contains classes that handle layout of displayables on
 # the screen.
 
+from __future__ import print_function
+
 import renpy.display
 import pygame_sdl2 as pygame
 
@@ -39,6 +41,7 @@ class Viewport(renpy.display.layout.Container):
     __version__ = 5
 
     arrowkeys = False
+    pagekeys = False
 
     def after_upgrade(self, version):
         if version < 1:
@@ -87,6 +90,7 @@ class Viewport(renpy.display.layout.Container):
                  yinitial=None,
                  replaces=None,
                  arrowkeys=False,
+                 pagekeys=False,
                  **properties):
 
         super(Viewport, self).__init__(style=style, **properties)
@@ -118,6 +122,7 @@ class Viewport(renpy.display.layout.Container):
         self.mousewheel = mousewheel
         self.draggable = draggable
         self.arrowkeys = arrowkeys
+        self.pagekeys = pagekeys
 
         # Layout participates in the focus system so drags get migrated.
         self.focusable = draggable or arrowkeys
@@ -410,6 +415,24 @@ class Viewport(renpy.display.layout.Container):
                 else:
                     raise renpy.display.core.IgnoreEvent()
 
+        if self.pagekeys:
+
+            if renpy.display.behavior.map_event(ev, 'viewport_pageup'):
+
+                rv = self.yadjustment.change(self.yadjustment.value - self.yadjustment.page)
+                if rv is not None:
+                    return rv
+                else:
+                    raise renpy.display.core.IgnoreEvent()
+
+            if renpy.display.behavior.map_event(ev, 'viewport_pagedown'):
+
+                rv = self.yadjustment.change(self.yadjustment.value + self.yadjustment.page)
+                if rv is not None:
+                    return rv
+                else:
+                    raise renpy.display.core.IgnoreEvent()
+
         if inside and self.draggable:
 
             if renpy.display.behavior.map_event(ev, 'viewport_drag_start'):
